RawResponse

Struct RawResponse 

pub struct RawResponse { /* private fields */ }
An in-memory HTTP response as returned by the shell, used in the middleware chain.

Implementations

Source

impl RawResponse

pub fn status(&self) -> StatusCode

Get the HTTP status code.

Examples
let res = client.get("https://httpbin.org/get").await?;
assert_eq!(res.status(), 200);
pub fn version(&self) -> Option<Version>

Get the HTTP protocol version.

Examples
use crux_http::http::Version;
let res = client.get("https://httpbin.org/get").await?;
assert_eq!(res.version(), Some(Version::HTTP_11));
pub fn header_all(&self, name: impl AsHeaderName) -> GetAll<'_, HeaderValue>

Get all values for a header name.

pub fn header(&self, name: impl AsHeaderName) -> Option<&HeaderValue>

Get a header value by name (returns the first value for that name).

Examples
let res = client.get("https://httpbin.org/get").await?;
assert!(res.header("Content-Length").is_some());
pub fn header_mut( &mut self, name: impl AsHeaderName, ) -> Option<&mut HeaderValue>

Get a header value mutably.

pub fn remove_header(&mut self, name: impl AsHeaderName) -> Option<HeaderValue>

Remove a header.

pub fn insert_header( &mut self, name: impl IntoHeaderName, value: HeaderValue, ) -> Option<HeaderValue>

Insert an HTTP header, replacing any existing value.

Returns the previous value for that header name, if any.

pub fn append_header( &mut self, name: impl IntoHeaderName, value: HeaderValue, ) -> bool

Append an HTTP header, keeping any existing values.

Returns true if the value was appended to an existing entry, false if it was the first value for that name.

pub fn iter(&self) -> Iter<'_, HeaderValue>

An iterator visiting all header (name, value) pairs in arbitrary order.

pub fn iter_mut(&mut self) -> IterMut<'_, HeaderValue>

An iterator visiting all header (name, value) pairs with mutable values.

pub fn header_names(&self) -> Keys<'_, HeaderValue>

An iterator visiting all header names in arbitrary order.

pub fn header_values(&self) -> Values<'_, HeaderValue>

An iterator visiting all header values in arbitrary order.

pub fn content_type(&self) -> Option<Mime>

Get the response content type as a Mime.

Examples
let res = client.get("https://httpbin.org/json").await?;
assert_eq!(res.content_type(), Some(mime::APPLICATION_JSON));
pub fn len(&self) -> Option<usize>

Get the length of the body in bytes.

pub fn is_empty(&self) -> Option<bool>

Returns true if the body is empty.

pub fn body_bytes(&mut self) -> Result<Vec<u8>>

Reads the entire response body into a byte buffer, leaving it empty.

Errors

This function currently never returns an error; the Result wrapper is kept for API consistency.

Examples
let mut res = client.get("https://httpbin.org/get").await?;
let bytes: Vec<u8> = res.body_bytes()?;
pub fn body_string(&mut self) -> Result<String>

Reads the entire response body into a string.

Errors

Returns an error if the body contains invalid UTF-8.

Examples
let mut res = client.get("https://httpbin.org/get").await?;
let string: String = res.body_string()?;
pub fn body_json<T: DeserializeOwned>(&mut self) -> Result<T>

Reads and deserializes the entire response body from JSON.

Errors

Returns an error if deserialisation fails.

Examples
#[derive(Deserialize, Serialize)]
struct Ip { ip: String }
let mut res = client.get("https://api.ipify.org?format=json").await?;
let Ip { ip } = res.body_json()?;
pub fn body_form<T: DeserializeOwned>(&mut self) -> Result<T>

Reads and deserializes the entire response body from form encoding.

Errors

Returns an error if deserialisation fails.

Examples
#[derive(Deserialize, Serialize)]
struct Body { apples: u32 }
let mut res = client.get("https://api.example.com/v1/response").await?;
let Body { apples } = res.body_form()?;