Response

Struct Response 

pub struct Response<Body> { /* private fields */ }
An HTTP Response that will be passed to an app’s update function.

Implementations

Source

impl<Body> Response<Body>

pub fn status(&self) -> StatusCode

Get the HTTP status code.

Examples
assert_eq!(res.status(), 200);
pub fn version(&self) -> Option<Version>

Get the HTTP protocol version.

Examples
use crux_http::http::Version;
assert_eq!(res.version(), Some(Version::HTTP_11));
pub fn header_all(&self, name: impl AsHeaderName) -> GetAll<'_, HeaderValue>

Get all values for a header name.

pub fn header(&self, name: impl AsHeaderName) -> Option<&HeaderValue>

Get a header value.

Examples
assert!(res.header("Content-Length").is_some());
pub fn header_mut( &mut self, name: impl AsHeaderName, ) -> Option<&mut HeaderValue>

Get an HTTP header mutably.

pub fn remove_header(&mut self, name: impl AsHeaderName) -> Option<HeaderValue>

Remove a header.

pub fn insert_header( &mut self, name: impl IntoHeaderName, value: HeaderValue, ) -> Option<HeaderValue>

Insert an HTTP header, replacing any existing value.

Returns the previous value for that header name, if any.

pub fn append_header( &mut self, name: impl IntoHeaderName, value: HeaderValue, ) -> bool

Append an HTTP header, keeping any existing values.

Returns true if the value was appended to an existing entry, false if it was the first value for that name.

pub fn iter(&self) -> Iter<'_, HeaderValue>

An iterator visiting all header (name, value) pairs in arbitrary order.

pub fn iter_mut(&mut self) -> IterMut<'_, HeaderValue>

An iterator visiting all header (name, value) pairs with mutable values.

pub fn header_names(&self) -> Keys<'_, HeaderValue>

An iterator visiting all header names in arbitrary order.

pub fn header_values(&self) -> Values<'_, HeaderValue>

An iterator visiting all header values in arbitrary order.

pub fn content_type(&self) -> Option<Mime>

Get the response content type as a Mime.

Examples
assert_eq!(res.content_type(), Some(mime::APPLICATION_JSON));
pub fn body(&self) -> Option<&Body>

pub fn take_body(&mut self) -> Option<Body>

pub fn with_body<NewBody>(self, body: NewBody) -> Response<NewBody>

Source

impl Response<Vec<u8>>

pub fn body_bytes(&mut self) -> Result<Vec<u8>>

Reads the entire request body into a byte buffer.

Errors

Returns an error if the body has already been taken.

Examples
let bytes: Vec<u8> = res.body_bytes()?;
pub fn body_string(&mut self) -> Result<String>

Reads the entire response body into a string.

Errors

Returns an error if the body has already been taken or if it contains invalid UTF-8.

Examples
let string: String = res.body_string()?;
assert_eq!(string, "hello");
pub fn body_json<T: DeserializeOwned>(&mut self) -> Result<T>

Reads and deserializes the entire response body from JSON.

Errors

Returns an error if the body has already been taken or if deserialisation fails.

Examples
#[derive(Deserialize, Serialize)]
struct Ip { ip: String }
let Ip { ip } = res.body_json()?;
assert_eq!(ip, "127.0.0.1");